"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
  Contains a serie of method aimed at reducing the payload
*/
const simplifyAssignee = (issue) => {
    if (issue.fields.assignee !== null) {
        return {
            name: issue.fields.assignee.name,
            displayName: issue.fields.assignee.displayName,
        };
    }
    return null;
};
const simplifyIssue = (issue) => {
    return {
        id: issue.id,
        key: issue.key,
        summary: issue.fields.summary,
        closedAt: issue.closedAt,
        weekStart: issue.weekStart !== undefined ? issue.weekStart : null,
        status: {
            name: issue.fields.status.name,
            category: issue.fields.status.statusCategory.name,
        },
        type: {
            name: issue.fields.issuetype.name,
            iconUrl: issue.fields.issuetype.iconUrl,
        },
        points: issue.points,
        metrics: issue.metrics !== undefined ? issue.metrics : null,
        assignee: simplifyAssignee(issue),
    };
};
// Iteratively go through children to "simplify" them
const simplifyChildren = (issue) => {
    if (issue.isLeaf === true) {
        return simplifyIssue(issue);
    }
    return Object.assign(Object.assign({}, simplifyIssue(issue)), { children: issue.children.map((i) => simplifyChildren(i)) });
};
const optimizePayload = (payload) => {
    const slimInitiatives = payload.initiatives.map((initiative) => {
        return Object.assign(Object.assign({}, simplifyIssue(initiative)), { metrics: initiative.metrics, weeks: initiative.weeks
                .filter((w) => w.list.length > 0)
                .map((week) => {
                return Object.assign(Object.assign({}, week), { list: week.list.map((i) => simplifyIssue(i)) });
            }), children: initiative.children.map((c) => simplifyChildren(c)) });
    });
    const orphanIssues = payload.orphanIssues.map((week) => {
        return Object.assign(Object.assign({}, week), { list: week.list.map((i) => simplifyIssue(i)) });
    });
    const futureCompletion = payload.futureCompletion.map((initiative) => {
        return Object.assign(Object.assign({}, simplifyIssue(initiative)), { team: initiative.team, metrics: initiative.metrics, weeks: initiative.weeks
                .filter((w) => w.issues.count > 0 || w.points.count > 0)
                .map((week) => {
                return Object.assign(Object.assign({}, week), { list: week.list.map((i) => simplifyIssue(i)) });
            }) });
    });
    return Object.assign(Object.assign({}, payload), { initiatives: slimInitiatives, orphanIssues: orphanIssues, futureCompletion: futureCompletion });
};
exports.default = optimizePayload;
